|Documentation Status| |Linux Build| |Windows Build|

autorelease
===========

Tools for keeping release behavior clean. Eventually will integrate with
other release helpers (probably ``zest.releaser``).

.. |Documentation Status| image:: https://readthedocs.org/projects/autorelease/badge/?version=latest
   :target: http://autorelease.readthedocs.io/en/latest/?badge=latest
.. |Linux Build| image:: https://travis-ci.org/dwhswenson/autorelease.svg?branch=master
   :target: https://travis-ci.org/dwhswenson/autorelease
.. |Windows Build| image:: https://ci.appveyor.com/api/projects/status/ox0c6u5gobk5ksat/branch/master?svg=true
   :target: https://ci.appveyor.com/project/dwhswenson/autorelease/branch/master
